@@ -1,6 +1,9 @@
 `cdf.ensembleBMAgamma0` <-
 function(fit, ensembleData, values, dates = NULL, ...) 
 {
+ powfun <- function(x,power) x^power
+ powinv <- function(x,power) x^(1/power)
+
  weps <- 1.e-4
 
  M <- matchEnsembleMembers(fit,ensembleData)
@@ -36,7 +39,7 @@ function(fit, ensembleData, values, dates = NULL, ...)
 
   }
 
- ensDates <- ensembleDates(ensembleData)
+ ensDates <- ensembleValidDates(ensembleData)
 
 ## match dates in data with dateTable
  if (is.null(ensDates) || all(is.na(ensDates))) {
@@ -48,7 +51,7 @@ function(fit, ensembleData, values, dates = NULL, ...)
 ## remove instances missing dates
    if (any(M <- is.na(ensDates))) {
      ensembleData <- ensembleData[!M,]
-     ensDates <- ensembleDates(ensembleData)
+     ensDates <- ensembleValidDates(ensembleData)
    }
    Dates <- as.character(ensDates)
    L <- as.logical(match( Dates, dates, nomatch=0))
@@ -86,7 +89,7 @@ function(fit, ensembleData, values, dates = NULL, ...)
      
        VAR <- fit$varCoefs[1,k] + fit$varCoefs[2,k]*f
         
-       fTrans <- sapply(f, fit$transformation)
+       fTrans <- sapply(f, powfun, power = fit$power)
 
        MEAN <- apply(rbind(1, fTrans) * fit$biasCoefs[,,k], 2, sum)
 
@@ -99,7 +102,7 @@ function(fit, ensembleData, values, dates = NULL, ...)
          W <- W[!M]/sum(W[!M])
        }
 
-       CDF[i,] <- sapply( sapply( values, fit$transformation), 
+       CDF[i,] <- sapply( sapply( values, powfun, power = fit$power), 
                           cdfBMAgamma0, WEIGHTS = W, 
                           PROB0 = PROB0[!M], MEAN = MEAN[!M], VAR = VAR[!M]) 
     }
