@@ -1,6 +1,9 @@
 `crps.fitBMAgamma0` <-
 function(fit, ensembleData, nSamples=NULL, seed=NULL, dates=NULL, ...) 
 {
+ powfun <- function(x,power) x^power
+ powinv <- function(x,power) x^(1/power)
+
  weps <- 1.e-4
 
  if (!is.null(dates)) warning("dates ignored")
@@ -44,7 +47,7 @@ function(fit, ensembleData, nSamples=NULL, seed=NULL, dates=NULL, ...)
 
        VAR <- fit$varCoefs[1] + fit$varCoefs[2]*f
 
-       fTrans <- sapply(f, fit$transformation)
+       fTrans <- sapply(f, powfun, power = fit$power)
 
        MEAN <- apply(rbind(1, fTrans) * fit$biasCoefs, 2, sum)
 
@@ -54,15 +57,16 @@ function(fit, ensembleData, nSamples=NULL, seed=NULL, dates=NULL, ...)
        PROB0 <- sapply(apply(rbind( 1, fTrans, f==0) * fit$prob0coefs,
                               2,sum), inverseLogit)
 
-       W <- WEIGHTS
-       if (any(M)) {  
-         W <- W + weps
+       if (sum(!M) > 1) {  
+         W <- WEIGHTS + weps
          W <- W[!M]/sum(W[!M])
+         SAMPLES <- sample( (1:nForecasts)[!M], size = nSamples, 
+                            replace = TRUE, prob = W)
+        }
+       else {
+         SAMPLES <- rep( (1:nForecasts)[!M], nSamples)
        }
 
-       SAMPLES <- sample( (1:nForecasts)[!M], size = nSamples, 
-                          replace = TRUE, prob = W)
-
        tab <- table(SAMPLES)
 
        tab <- table(unlist(apply( cbind(as.numeric(names(tab)), tab), 1,
@@ -79,8 +83,7 @@ function(fit, ensembleData, nSamples=NULL, seed=NULL, dates=NULL, ...)
            
 # model is fit to the cube root of the forecast
 
-         S <- sapply(as.vector(unlist(S)),
-                           fit$inverseTransformation)
+         S <- sapply(as.vector(unlist(S)), powinv, power = fit$power)
 
          SAMPLES <- c(rep(0, tab[1]), S)
        }
