@@ -1,5 +1,5 @@
 `ensembleBMAnormal` <-
-function(ensembleData, dates = NULL, trainingRule = list(length=NA, lag=NA), 
+function(ensembleData, trainingDays, dates = NULL, 
          control = controlBMAnormal(), exchangeable = NULL, minCRPS = FALSE)
 {
  if (!inherits(ensembleData,"ensembleData")) stop("not an ensembleData object")
@@ -8,14 +8,13 @@ function(ensembleData, dates = NULL, trainingRule = list(length=NA, lag=NA),
 
  warmStart <- FALSE
 
- trainingRule <- as.list(trainingRule)
+ if (is.list(trainingDays)) trainingsDays <- trainingsDays[[1]]
 
- if (is.null(trainingRule$length) || is.na(trainingRule$length) ||
-     is.null(trainingRule$lag) || is.na(trainingRule$lag))
-   stop("length and lag must be specified in training rule")
+ if (length(trainingDays) > 1 || trainingDays <= 0 
+       || (trainingDays - trunc(trainingDays)) != 0) 
+   stop("trainingDays improperly specified")
 
- if (trainingRule$length < 0 || trainingRule$lag < 0) 
-   stop("improperly specified training rule")
+ lag <- ceiling( ensembleFhour(ensembleData) / 24 )
 
  ensMemNames <- ensembleMemberLabels(ensembleData)
  nForecasts <- length(ensMemNames)
@@ -27,19 +26,19 @@ function(ensembleData, dates = NULL, trainingRule = list(length=NA, lag=NA),
 
  M <- apply(ensembleForecasts(ensembleData), 1, function(z) all(is.na(z)))
  M <- M | is.na(ensembleVerifObs(ensembleData))
- M <- M | is.na(ensembleDates(ensembleData))
+ M <- M | is.na(ensembleValidDates(ensembleData))
  ensembleData <- ensembleData[!M,]
  
  nObs <- ensembleNobs(ensembleData)
  if (!nObs) stop("no observations")
 
- ensDates <- ensembleDates(ensembleData)
+ ensDates <- ensembleValidDates(ensembleData)
  if (is.null(ensDates)) stop("dates unavailable")
 
  Dates <- as.character(ensDates)
  DATES <- sort(unique(Dates))
 
- if (trainingRule$length+trainingRule$lag > length(DATES)) 
+ if (trainingDays+lag > length(DATES)) 
    stop("insufficient training data")
 
  julianDATES <- ymdhTOjul(DATES)
@@ -48,8 +47,8 @@ function(ensembleData, dates = NULL, trainingRule = list(length=NA, lag=NA),
 
 ## dates that can be modeled by the training data (ignoring gaps)
 
- Jdates <- seq(from = julianDATES[trainingRule$length]+trainingRule$lag*incr,
-               to = max(julianDATES)+trainingRule$lag*incr, by = incr)
+ Jdates <- seq(from = julianDATES[trainingDays]+lag*incr,
+               to = max(julianDATES)+lag*incr, by = incr)
 
 ## determine the modeling dates
 
@@ -126,7 +125,7 @@ function(ensembleData, dates = NULL, trainingRule = list(length=NA, lag=NA),
  names(nIter) <- names(loglikelihood) <- dates
 
  L <- length(juliandates)
- twin <- 1:trainingRule$length
+ twin <- 1:trainingDays
 
 ## temp <- data.frame(julian = julianDATES,date = DATES)
 ## print(temp)
@@ -138,14 +137,14 @@ function(ensembleData, dates = NULL, trainingRule = list(length=NA, lag=NA),
  l <- 0
  for(i in seq(along = juliandates)) {
 
-    I <- (juliandates[i]-trainingRule$lag*incr) >= julianDATES
+    I <- (juliandates[i]-lag*incr) >= julianDATES
     if (!any(I)) stop("insufficient training data")
 
     j <- which(I)[sum(I)]
 
     if (j != l) {
 
-      twin <- (j+1) - (1:trainingRule$length)
+      twin <- (j+1) - (1:trainingDays)
       D <- as.logical(match(Dates, DATES[twin], nomatch=0))
       if (!any(D)) stop("this should not happen")
       cat("modeling for date", dates[i], "...")
@@ -212,7 +211,7 @@ function(ensembleData, dates = NULL, trainingRule = list(length=NA, lag=NA),
 
  }
 
- structure(list(trainingRule = c(trainingRule, list(table = trainTable)),
+ structure(list(training = list(days=trainingDays,lag= lag,table=trainTable),
                 biasCoefs = biasCoefs, sd = sd, weights = weights,
                 nIter = nIter, exchangeable = exchangeable),
                 call = match.call(), class = "ensembleBMAnormal")
